Learn R Programming

chi2x3way (version 1.1)

olive: Agresti's data (1990), three-way contingency table

Description

The data consists of 6 rows, 3 columns and 2 tubes. The rows represent the preference for black olives of Armed Forces personnel, the columns are concerned with the location and the tubes with the urbanization.

Usage

data(olive)

Arguments

Format

The format is: row names [1:6] "A" "B" "C" "D" "E" "F" col names [1:3] "NW" "NE" "SW" tube names [1:2] "urban" "rural"

References

Agresti A (1990) Categorical Data Analysis (pg. 335). John Wiley & Sons.

Examples

Run this code
data(olive)
dim(olive)
dimnames(olive)

Run the code above in your browser using DataLab