Learn R Programming

chi2x3way (version 1.1)

print.chi2x3way: Printing function of the results of the three-way index partition

Description

This function prints the results of the three-way index partition. The input parameter is the name of the output of the main function Chi2for3way.

Usage

"print"(x, digits = 3, ...)

Arguments

x
The name of the output object, for example say res, used with the main function Chi2for3way.
digits
The minimum number of decimal places, digits, used for displaying the numerical summaries of the analysis. By default, digits = 3.
...
Further arguments passed to or from other methods.

Value

itemXThe three-way contingency table.

References

Beh EJ and Lombardo R (2014) Correspondence Analysis: Theory, Practice and New Strategies. John Wiley & Sons. Carlier A Kroonenberg PM (1996) Biplots and decompositions in two-way and three-way correspondence analysis. Psychometrika, 61, 355-373. Lancaster H O (1951) Complex contingency tables treated by the partition of the chi-square. Journal of Royal Statistical Society, Series B, 13, 242-249. Loisel S and Takane Y (2016) Partitions of Pearson's chi-square ststistic for frequency tables: A comprehensive account. Computational Statistics, 31, 1429-1452. Lombardo R Carlier A D'Ambra L (1996) Nonsymmetric correspondence analysis for three-way contingency tables. Methodologica, 4, 59-80.

Examples

Run this code
data(olive)
resolive<-chi2x3way(olive,scen=2,simulation=FALSE) 
print.chi2x3way(resolive)

Run the code above in your browser using DataLab