Learn R Programming

chi2x3way (version 1.1)

tau3scen1: Marcotorchino's index for three-way contingency tables under Scenario 1

Description

It provides the partition of the Marcotorchino's index and its related $C_M$-statistic under the Scenario 1 when probabilities are homogeneous.

Usage

tau3scen1(X, pi=rep(1/dim(X)[[1]],dim(X)[[1]]), pj=rep(1/dim(X)[[2]],dim(X)[[2]]), pk=rep(1/dim(X)[[3]],dim(X)[[3]]), digits = 3)

Arguments

X
The three-way contingency table.
pi
The input parameter for specifying the theoretical probabilities of rows categories. When scen = 1, they can be prescribed by the analyst. By default, they are set equal among the categories, homogeneous margins (uniform probabilities), that is pi = rep(1/dim(X)[[1]],dim(X)[[1]]).
pj
The input parameter for specifying the theoretical probabilities of columns categories. When scen = 1, they can be prescribed by the analyst. By default, they are set equal among the categories, homogeneous margins (uniform probabilities), that is pj = rep(1/dim(X)[[2]],dim(X)[[2]]).
pk
The input parameter for specifying the theoretical probabilities of tube categories. When scen = 1, they can be prescribed by the analyst. By default, they are set equal among the categories, homogeneous margins (uniform probabilities), that is pk = rep(1/dim(X)[[3]],dim(X)[[3]]).
digits
The minimum number of decimal places, digits, used for displaying the numerical summaries of the analysis. By default, digits = 3.

Value

Description of the output returned Description of the output returned

References

Beh EJ and Lombardo R (2014) Correspondence Analysis: Theory, Practice and New Strategies. John Wiley & Sons. Lancaster H O (1951) Complex contingency tables treated by the partition of the chi-square. Journal of Royal Statistical Society, Series B, 13, 242-249. Loisel S and Takane Y (2016) Partitions of Pearson's chi-square ststistic for frequency tables: A comprehensive account. Computational Statistics, 31, 1429-1452. Lombardo R Carlier A D'Ambra L (1996) Nonsymmetric correspondence analysis for three-way contingency tables. Methodologica, 4, 59-80. Marcotorchino F (1985) Utilisation des comparaisons par paires en statistique des contingencies: Partie III. Etude du Centre Scientifique, IBM, France. No F 081

Examples

Run this code
data(olive)
tau3scen1(olive)

Run the code above in your browser using DataLab