chi3scen1(X, pi=rep(1/dim(X)[[1]],dim(X)[[1]]), pj=rep(1/dim(X)[[2]],dim(X)[[2]]),
pk=rep(1/dim(X)[[3]],dim(X)[[3]]), digits = 3)scen = 1, they can be prescribed by the analyst. By default, they are set equal among the categories, homogeneous margins (uniform probabilities), that is
pi = rep(1/dim(X)[[1]],dim(X)[[1]]).scen = 1, they can be prescribed by the analyst. By default, they are set equal among the categories, homogeneous margins (uniform probabilities), that is
pj = rep(1/dim(X)[[2]],dim(X)[[2]]).scen = 1, they can be prescribed by the analyst. By default, they are set equal among the categories, homogeneous margins (uniform probabilities), that is
pk = rep(1/dim(X)[[3]],dim(X)[[3]]).digits, used for displaying the numerical summaries of the analysis.
By default, digits = 3.
##---- Should be DIRECTLY executable !! ----
data(olive)
chi3scen1(olive)
Run the code above in your browser using DataLab