chi3scen2:
Pearson's index for three-way contingency tables under Scenario 2
Description
It provides the Pearson's index, e.g. chi-square index, partitioning under the Scenario 2 when probabilities are set equal to the observed margin frequencies
Usage
chi3scen2(X, digits = 3)
Arguments
X
The three-way contingency table.
digits
The minimum number of decimal places, digits, used for displaying the numerical summaries of the analysis.
By default, digits = 3.
Value
References
Beh EJ and Lombardo R (2014) Correspondence Analysis: Theory, Practice and New Strategies. John Wiley & Sons.
Carlier A Kroonenberg PM (1996) Biplots and decompositions in two-way and three-way correspondence analysis. Psychometrika, 61, 355-373.
Lancaster H O (1951) Complex contingency tables treated by the partition of the chi-square. Journal of Royal Statistical Society, Series B, 13, 242-249.
Loisel S and Takane Y (2016) Partitions of Pearson's chi-square ststistic for frequency tables: A comprehensive account. Computational Statistics, 31, 1429-1452.