Usage
tau3scen1(X, pi=rep(1/dim(X)[[1]],dim(X)[[1]]), pj=rep(1/dim(X)[[2]],dim(X)[[2]]),
pk=rep(1/dim(X)[[3]],dim(X)[[3]]), digits = 3)
Arguments
X
The three-way contingency table.
pi
The input parameter for specifying the theoretical probabilities of rows categories. When scen = 1, they can be prescribed by the analyst.
By default, they are set equal among the categories, homogeneous margins (uniform probabilities), that is pi = rep(1/dim(X)[[1]],dim(X)[[1]]).
pj
The input parameter for specifying the theoretical probabilities of columns categories. When scen = 1, they can be prescribed by the analyst.
By default, they are set equal among the categories, homogeneous margins (uniform probabilities), that is pj = rep(1/dim(X)[[2]],dim(X)[[2]]).
pk
The input parameter for specifying the theoretical probabilities of tube categories. When scen = 1, they can be prescribed by the analyst.
By default, they are set equal among the categories, homogeneous margins (uniform probabilities), that is pk = rep(1/dim(X)[[3]],dim(X)[[3]]).
digits
The minimum number of decimal places, digits, used for displaying the numerical summaries of the analysis. By default, digits = 3.